@@ -461,6 +461,7 @@ public class GL implements GLConstants
 	public static native void glGetTexImage(int target, int level, int format, int type, int[] pixels);
 
 	// 1.1 functions 
+	public static native int glGenTexture();
 	public static int[] glGenTextures(int num)
 	{
 		int[] texstureNameArray = new int[num];
@@ -473,6 +474,7 @@ public class GL implements GLConstants
 	}
 	public static native void glGenTextures(int n, int[] texstureNameArray);
 
+	public static native void glDeleteTexture(int texture);
 	public static void glDeleteTextures(int[] texstureNameArray)
 	{
 		glDeleteTextures(texstureNameArray.length, texstureNameArray);
