@@ -2728,6 +2728,15 @@ GL::glGetTexImage (jint target, jint level, jint format, jint type, jintArray pi
 
 
 // 1.1 functions 
+jint
+GL::glGenTexture ()
+{
+	JvInitClass(&GL::class$);
+	GLuint texture;
+	::glGenTextures(1, &texture);
+	return (jint)texture;
+}
+
 void
 GL::glGenTextures (jint n, jintArray textureNameArray)
 {
@@ -2737,6 +2746,12 @@ GL::glGenTextures (jint n, jintArray textureNameArray)
 	::glGenTextures(n, textures);
 }
 
+void
+GL::glDeleteTexture (jint texture)
+{
+	JvInitClass(&GL::class$);
+	::glDeleteTextures(1, (const GLuint*)&texture);
+}
 
 void
 GL::glDeleteTextures (jint n, jintArray textureNameArray)
