@@ -1,6 +1,6 @@
 import glut4gcj.*;
 
-class SimpleWindow extends GLUT implements DisplayFunc
+public class SimpleWindow extends GLUT implements DisplayFunc
 {
 	public void display()
 	{
